@@ -23,28 +23,26 @@ SearchStore::SearchStore(QObject *parent)
 {
 }
 
-SearchStore::~SearchStore()
-{
-}
+SearchStore::~SearchStore() = default;
 
 QUrl SearchStore::url(int)
 {
-    return QUrl();
+    return {};
 }
 
 QString SearchStore::icon(int)
 {
-    return QString();
+    return {};
 }
 
 QString SearchStore::text(int)
 {
-    return QString();
+    return {};
 }
 
 QString SearchStore::property(int, const QString &)
 {
-    return QString();
+    return {};
 }
 
 Q_GLOBAL_STATIC(SearchStore::List, s_overrideSearchStores)
@@ -80,7 +78,7 @@ SearchStore::List SearchStore::searchStores()
 
     const QStringList paths = QCoreApplication::libraryPaths();
     for (const QString &libraryPath : paths) {
-        QString path(libraryPath + QStringLiteral("/akonadi"));
+        const QString path(libraryPath + QStringLiteral("/akonadi"));
         QDir dir(path);
 
         if (!dir.exists()) {
